summaryrefslogtreecommitdiffstats
path: root/kopete
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-04-13 01:04:19 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-04-13 01:04:19 -0500
commit008eae43da364c9a910416652cf277c4ef5895c9 (patch)
tree5f9060ce2395120f3ce327d444b035a6ece978a4 /kopete
parent2bc02dc6e21b9f38a76c6733a0931c7ebc944547 (diff)
downloadtdenetwork-008eae43da364c9a910416652cf277c4ef5895c9.tar.gz
tdenetwork-008eae43da364c9a910416652cf277c4ef5895c9.zip
Fix inadvertent "TQ" changes.
Diffstat (limited to 'kopete')
-rw-r--r--kopete/kopete/chatwindow/chatmessagepart.cpp6
-rw-r--r--kopete/plugins/motionautoaway/motionawayplugin.cpp4
-rw-r--r--kopete/plugins/smpppdcs/onlineinquiry.h4
-rw-r--r--kopete/protocols/groupwise/libgroupwise/gwfield.h4
-rw-r--r--kopete/protocols/groupwise/libgroupwise/tasks/chatpropertiestask.cpp2
-rw-r--r--kopete/protocols/groupwise/libgroupwise/tasks/getchatsearchresultstask.cpp2
-rw-r--r--kopete/protocols/irc/ircprotocol.cpp2
-rw-r--r--kopete/protocols/irc/libkirc/kircengine_commands.cpp2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/common.h4
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/messagequeue.h6
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/network.cc2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/network.h6
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/sigslot.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/socket.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc6
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.c12
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.h4
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msqueue.h4
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.cc18
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.h18
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h6
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc12
-rw-r--r--kopete/protocols/msn/webcam/libmimic/mimic-private.h6
-rw-r--r--kopete/protocols/msn/webcam/libmimic/mimic.c6
24 files changed, 70 insertions, 70 deletions
diff --git a/kopete/kopete/chatwindow/chatmessagepart.cpp b/kopete/kopete/chatwindow/chatmessagepart.cpp
index f383e25a..fbd8fa2c 100644
--- a/kopete/kopete/chatwindow/chatmessagepart.cpp
+++ b/kopete/kopete/chatwindow/chatmessagepart.cpp
@@ -88,7 +88,7 @@
#if !(KDE_IS_VERSION(3,3,90))
//From tdelibs/khtml/misc/htmltags.h
// used in ChatMessagePart::copy()
-#define ID_BLOCKTQUOTE 12
+#define ID_BLOCKQUOTE 12
#define ID_BR 14
#define ID_DD 22
#define ID_DIV 26
@@ -872,7 +872,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
case ID_TD: case ID_TH: case ID_HR:
case ID_OL: case ID_UL: case ID_LI:
case ID_DD: case ID_DL: case ID_DT:
- case ID_PRE: case ID_BLOCKTQUOTE: case ID_DIV:
+ case ID_PRE: case ID_BLOCKQUOTE: case ID_DIV:
if (!hasNewLine)
text += "\n";
hasNewLine = true;
@@ -902,7 +902,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
case ID_TD: case ID_TH: case ID_HR:
case ID_OL: case ID_UL: case ID_LI:
case ID_DD: case ID_DL: case ID_DT:
- case ID_PRE: case ID_BLOCKTQUOTE: case ID_DIV:
+ case ID_PRE: case ID_BLOCKQUOTE: case ID_DIV:
if (!hasNewLine)
text += "\n";
hasNewLine = true;
diff --git a/kopete/plugins/motionautoaway/motionawayplugin.cpp b/kopete/plugins/motionautoaway/motionawayplugin.cpp
index 237e0e0e..ea37878d 100644
--- a/kopete/plugins/motionautoaway/motionawayplugin.cpp
+++ b/kopete/plugins/motionautoaway/motionawayplugin.cpp
@@ -84,7 +84,7 @@ typedef __signed__ long long __s64;
#define DEF_WIDTH 352
#define DEF_HEIGHT 288
-#define DEF_TQUALITY 50
+#define DEF_QUALITY 50
#define DEF_CHANGES 5000
#define DEF_POLL_INTERVAL 1500
@@ -104,7 +104,7 @@ MotionAwayPlugin::MotionAwayPlugin( TQObject *parent, const char *name, const TQ
/* This should be read from config someday may be */
m_width = DEF_WIDTH;
m_height = DEF_HEIGHT;
- m_quality = DEF_TQUALITY;
+ m_quality = DEF_QUALITY;
m_maxChanges = DEF_CHANGES;
m_gap = DEF_GAP;
diff --git a/kopete/plugins/smpppdcs/onlineinquiry.h b/kopete/plugins/smpppdcs/onlineinquiry.h
index 278c1e9f..c9b5221a 100644
--- a/kopete/plugins/smpppdcs/onlineinquiry.h
+++ b/kopete/plugins/smpppdcs/onlineinquiry.h
@@ -14,8 +14,8 @@
*************************************************************************
*/
-#ifndef ONLINEINTQUIRY_H
-#define ONLINEINTQUIRY_H
+#ifndef ONLINEINQUIRY_H
+#define ONLINEINQUIRY_H
#include "iconnector.h"
diff --git a/kopete/protocols/groupwise/libgroupwise/gwfield.h b/kopete/protocols/groupwise/libgroupwise/gwfield.h
index 4e1b1f94..f4c52205 100644
--- a/kopete/protocols/groupwise/libgroupwise/gwfield.h
+++ b/kopete/protocols/groupwise/libgroupwise/gwfield.h
@@ -122,14 +122,14 @@
// GW7
#define NM_A_FA_CUSTOM_STATUSES "NM_A_FA_CUSTOM_STATUSES"
#define NM_A_FA_STATUS "NM_A_FA_STATUS"
-#define NM_A_UD_TQUERY_COUNT "NM_A_UD_TQUERY_COUNT"
+#define NM_A_UD_QUERY_COUNT "NM_A_UD_QUERY_COUNT"
#define NM_A_FA_CHAT "NM_A_FA_CHAT"
#define NM_A_DISPLAY_NAME "nnmDisplayName"
#define NM_A_CHAT_OWNER_DN "nnmChatOwnerDN"
#define NM_A_UD_PARTICIPANTS "NM_A_UD_PARTICIPANTS"
#define NM_A_DESCRIPTION "nnmDescription"
#define NM_A_DISCLAIMER "nnmDisclaimer"
-#define NM_A_TQUERY "nnmQuery"
+#define NM_A_QUERY "nnmQuery"
#define NM_A_ARCHIVE "nnmArchive"
#define NM_A_MAX_USERS "nnmMaxUsers"
#define NM_A_SZ_TOPIC "NM_A_SZ_TOPIC"
diff --git a/kopete/protocols/groupwise/libgroupwise/tasks/chatpropertiestask.cpp b/kopete/protocols/groupwise/libgroupwise/tasks/chatpropertiestask.cpp
index 4dceacc1..7f60f3c5 100644
--- a/kopete/protocols/groupwise/libgroupwise/tasks/chatpropertiestask.cpp
+++ b/kopete/protocols/groupwise/libgroupwise/tasks/chatpropertiestask.cpp
@@ -82,7 +82,7 @@ bool ChatPropertiesTask::take( Transfer * transfer )
m_description = sf->value().toString();
else if ( sf->tag() == NM_A_DISCLAIMER )
m_disclaimer = sf->value().toString();
- else if ( sf->tag() == NM_A_TQUERY )
+ else if ( sf->tag() == NM_A_QUERY )
m_query = sf->value().toString();
else if ( sf->tag() == NM_A_ARCHIVE )
m_archive = sf->value().toString();
diff --git a/kopete/protocols/groupwise/libgroupwise/tasks/getchatsearchresultstask.cpp b/kopete/protocols/groupwise/libgroupwise/tasks/getchatsearchresultstask.cpp
index a62cf022..8104ec24 100644
--- a/kopete/protocols/groupwise/libgroupwise/tasks/getchatsearchresultstask.cpp
+++ b/kopete/protocols/groupwise/libgroupwise/tasks/getchatsearchresultstask.cpp
@@ -42,7 +42,7 @@ void GetChatSearchResultsTask::poll( int queryHandle )
{
Field::FieldList lst;
lst.append( new Field::SingleField( NM_A_UD_OBJECT_ID, 0, NMFIELD_TYPE_UDWORD, queryHandle ) );
- lst.append( new Field::SingleField( NM_A_UD_TQUERY_COUNT, 0, NMFIELD_TYPE_UDWORD, 10 ) );
+ lst.append( new Field::SingleField( NM_A_UD_QUERY_COUNT, 0, NMFIELD_TYPE_UDWORD, 10 ) );
createTransfer( "getchatsearchresults", lst );
}
diff --git a/kopete/protocols/irc/ircprotocol.cpp b/kopete/protocols/irc/ircprotocol.cpp
index a8b39299..96d905c0 100644
--- a/kopete/protocols/irc/ircprotocol.cpp
+++ b/kopete/protocols/irc/ircprotocol.cpp
@@ -284,7 +284,7 @@ IRCProtocol::IRCProtocol( TQObject *parent, const char *name, const TQStringList
Kopete::CommandHandler::commandHandler()->registerAlias( this, TQString::fromLatin1("msg"),
TQString::fromLatin1("query %s"),
- i18n("USAGE: /msg <nickname> [<message>] - Alias for TQUERY <nickname> <message>."), Kopete::CommandHandler::SystemAlias, 1 );
+ i18n("USAGE: /msg <nickname> [<message>] - Alias for QUERY <nickname> <message>."), Kopete::CommandHandler::SystemAlias, 1 );
TQObject::connect( Kopete::ChatSessionManager::self(), TQT_SIGNAL(aboutToDisplay(Kopete::Message &)),
this, TQT_SLOT(slotMessageFilter(Kopete::Message &)) );
diff --git a/kopete/protocols/irc/libkirc/kircengine_commands.cpp b/kopete/protocols/irc/libkirc/kircengine_commands.cpp
index acea30e7..8aa5916e 100644
--- a/kopete/protocols/irc/libkirc/kircengine_commands.cpp
+++ b/kopete/protocols/irc/libkirc/kircengine_commands.cpp
@@ -38,7 +38,7 @@ void Engine::bindCommands()
bind("PONG", this, TQT_SLOT(pong(KIRC::Message &)), 0, 0);
bind("PRIVMSG", this, TQT_SLOT(privmsg(KIRC::Message &)), 1, 1);
bind("QUIT", this, TQT_SLOT(quit(KIRC::Message &)), 0, 0);
-// bind("STQUIT", this, TQT_SLOT(squit(KIRC::Message &)), 1, 1);
+// bind("SQUIT", this, TQT_SLOT(squit(KIRC::Message &)), 1, 1);
bind("TOPIC", this, TQT_SLOT(topic(KIRC::Message &)), 1, 1);
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/common.h b/kopete/protocols/jabber/jingle/libjingle/talk/base/common.h
index 5f191beb..b21be2f1 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/common.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/common.h
@@ -178,8 +178,8 @@ inline void Assert(bool result, const char * function, const char * file, int li
#endif // !ENABLE_DEBUG
-#define COMPILE_TIME_ASSERT(expr) char CTA_UNITQUE_NAME[expr]
-#define CTA_UNITQUE_NAME MAKE_NAME(__LINE__)
+#define COMPILE_TIME_ASSERT(expr) char CTA_UNIQUE_NAME[expr]
+#define CTA_UNIQUE_NAME MAKE_NAME(__LINE__)
#define CTA_MAKE_NAME(line) MAKE_NAME2(line)
#define CTA_MAKE_NAME2(line) constraint_ ## line
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/messagequeue.h b/kopete/protocols/jabber/jingle/libjingle/talk/base/messagequeue.h
index cf8917d9..9b35b9af 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/messagequeue.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/messagequeue.h
@@ -25,8 +25,8 @@
* ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef __MESSAGETQUEUE_H__
-#define __MESSAGETQUEUE_H__
+#ifndef __MESSAGEQUEUE_H__
+#define __MESSAGEQUEUE_H__
#include "talk/base/basictypes.h"
#include "talk/base/criticalsection.h"
@@ -162,4 +162,4 @@ protected:
} // namespace cricket
-#endif // __MESSAGETQUEUE_H__
+#endif // __MESSAGEQUEUE_H__
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/network.cc b/kopete/protocols/jabber/jingle/libjingle/talk/base/network.cc
index 5274c29d..21b3a08f 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/network.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/network.cc
@@ -60,7 +60,7 @@ const double kLog2 = 0.693147180559945309417;
const double kLambda = kLog2 / kHalfLife;
// assume so-so quality unless data says otherwise
-const double kDefaultQuality = cricket::TQUALITY_FAIR;
+const double kDefaultQuality = cricket::QUALITY_FAIR;
typedef std::map<std::string,std::string> StrMap;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/network.h b/kopete/protocols/jabber/jingle/libjingle/talk/base/network.h
index 5f7d7216..2cc9128a 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/network.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/network.h
@@ -127,9 +127,9 @@ public:
};
-const double TQUALITY_BAD = 3.0;
-const double TQUALITY_FAIR = 3.35;
-const double TQUALITY_GOOD = 3.7;
+const double QUALITY_BAD = 3.0;
+const double QUALITY_FAIR = 3.35;
+const double QUALITY_GOOD = 3.7;
} // namespace cricket
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/sigslot.h b/kopete/protocols/jabber/jingle/libjingle/talk/base/sigslot.h
index 893d6a47..a37000bf 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/sigslot.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/sigslot.h
@@ -5,7 +5,7 @@
// License: Public domain. You are free to use this code however you like, with the proviso that
// the author takes on no responsibility or liability for any use.
//
-// TQUICK DOCUMENTATION
+// QUICK DOCUMENTATION
//
// (see also the full documentation at http://sigslot.sourceforge.net/)
//
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/socket.h b/kopete/protocols/jabber/jingle/libjingle/talk/base/socket.h
index 7c240802..d4a49d96 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/socket.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/socket.h
@@ -84,7 +84,7 @@
#define ENOTEMPTY WSAENOTEMPTY
#define EPROCLIM WSAEPROCLIM
#define EUSERS WSAEUSERS
-#define EDTQUOT WSAEDTQUOT
+#define EDQUOT WSAEDQUOT
#define ESTALE WSAESTALE
#define EREMOTE WSAEREMOTE
#undef EACCES
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc
index 24036b02..b65c9a20 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc
@@ -25,7 +25,7 @@
#define SAMPLE_RATE 1
// Speex settings
-//#define SPEEX_TQUALITY 8
+//#define SPEEX_QUALITY 8
// ORTP settings
#define MAX_RTP_SIZE 1500 // From mediastreamer
@@ -65,8 +65,8 @@ PortAudioMediaChannel::PortAudioMediaChannel() : mute_(false), play_(false), str
speex_decoder_ctl(speex_dec_state_, SPEEX_GET_FRAME_SIZE, &speex_frame_size_);
speex_frame_ = new float[speex_frame_size_];
- // int quality = SPEEX_TQUALITY;
- // speex_encoder_ctl(state, SPEEX_SET_TQUALITY, &quality);
+ // int quality = SPEEX_QUALITY;
+ // speex_encoder_ctl(state, SPEEX_SET_QUALITY, &quality);
// Initialize ORTP socket
struct sockaddr_in sockaddr;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.h
index 60c87411..89f91ad8 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.h
@@ -98,7 +98,7 @@ typedef struct _MSFilterClass
void (*destroy)(MSFilter *filter);
guint attributes;
#define FILTER_HAS_FIFOS (0x0001)
-#define FILTER_HAS_TQUEUES (0x0001<<1)
+#define FILTER_HAS_QUEUES (0x0001<<1)
#define FILTER_IS_SOURCE (0x0001<<2)
#define FILTER_IS_SINK (0x0001<<3)
#define FILTER_CAN_SYNC (0x0001<<4)
@@ -151,7 +151,7 @@ void ms_filter_destroy(MSFilter *f);
#define LINK_DEFAULT 0
#define LINK_FIFO 1
-#define LINK_TQUEUE 2
+#define LINK_QUEUE 2
#define MSFILTER_VERSION(a,b,c) (((a)<<2)|((b)<<1)|(c))
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msqueue.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msqueue.h
index ee8e1f44..7094b088 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msqueue.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msqueue.h
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
-#ifndef MSTQUEUE_H
-#define MSTQUEUE_H
+#ifndef MSQUEUE_H
+#define MSQUEUE_H
#include "msbuffer.h"
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.cc b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.cc
index 1eee5013..f89df149 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.cc
@@ -166,7 +166,7 @@ const TQName TQN_XSTREAM_XML_NOT_WELL_FORMED(true, NS_XSTREAM, "xml-not-well-for
const TQName TQN_XSTREAM_TEXT(true, NS_XSTREAM, "text");
const TQName TQN_TLS_STARTTLS(true, NS_TLS, "starttls");
-const TQName TQN_TLS_RETQUIRED(true, NS_TLS, "required");
+const TQName TQN_TLS_REQUIRED(true, NS_TLS, "required");
const TQName TQN_TLS_PROCEED(true, NS_TLS, "proceed");
const TQName TQN_TLS_FAILURE(true, NS_TLS, "failure");
@@ -199,15 +199,15 @@ const TQName TQN_STANZA_ITEM_NOT_FOUND(true, NS_STANZA, "item-not-found");
const TQName TQN_STANZA_JID_MALFORMED(true, NS_STANZA, "jid-malformed");
const TQName TQN_STANZA_NOT_ACCEPTABLE(true, NS_STANZA, "not-acceptable");
const TQName TQN_STANZA_NOT_ALLOWED(true, NS_STANZA, "not-allowed");
-const TQName TQN_STANZA_PAYMENT_RETQUIRED(true, NS_STANZA, "payment-required");
+const TQName TQN_STANZA_PAYMENT_REQUIRED(true, NS_STANZA, "payment-required");
const TQName TQN_STANZA_RECIPIENT_UNAVAILABLE(true, NS_STANZA, "recipient-unavailable");
const TQName TQN_STANZA_REDIRECT(true, NS_STANZA, "redirect");
-const TQName TQN_STANZA_REGISTRATION_RETQUIRED(true, NS_STANZA, "registration-required");
+const TQName TQN_STANZA_REGISTRATION_REQUIRED(true, NS_STANZA, "registration-required");
const TQName TQN_STANZA_REMOTE_SERVER_NOT_FOUND(true, NS_STANZA, "remote-server-not-found");
const TQName TQN_STANZA_REMOTE_SERVER_TIMEOUT(true, NS_STANZA, "remote-server-timeout");
const TQName TQN_STANZA_RESOURCE_CONSTRAINT(true, NS_STANZA, "resource-constraint");
const TQName TQN_STANZA_SERVICE_UNAVAILABLE(true, NS_STANZA, "service-unavailable");
-const TQName TQN_STANZA_SUBSCRIPTION_RETQUIRED(true, NS_STANZA, "subscription-required");
+const TQName TQN_STANZA_SUBSCRIPTION_REQUIRED(true, NS_STANZA, "subscription-required");
const TQName TQN_STANZA_UNDEFINED_CONDITION(true, NS_STANZA, "undefined-condition");
const TQName TQN_STANZA_UNEXPECTED_REQUEST(true, NS_STANZA, "unexpected-request");
const TQName TQN_STANZA_TEXT(true, NS_STANZA, "text");
@@ -242,7 +242,7 @@ const TQName TQN_SERVER_ERROR(true, NS_SERVER, "error");
const TQName TQN_SESSION_SESSION(true, NS_SESSION, "session");
-const TQName TQN_PRIVACY_TQUERY(true, NS_PRIVACY, "query");
+const TQName TQN_PRIVACY_QUERY(true, NS_PRIVACY, "query");
const TQName TQN_PRIVACY_ACTIVE(true, NS_PRIVACY, "active");
const TQName TQN_PRIVACY_DEFAULT(true, NS_PRIVACY, "default");
const TQName TQN_PRIVACY_LIST(true, NS_PRIVACY, "list");
@@ -252,11 +252,11 @@ const TQName TQN_PRIVACY_MESSAGE(true, NS_PRIVACY, "message");
const TQName TQN_PRIVACY_PRESENCE_IN(true, NS_PRIVACY, "presence-in");
const TQName TQN_PRIVACY_PRESENCE_OUT(true, NS_PRIVACY, "presence-out");
-const TQName TQN_ROSTER_TQUERY(true, NS_ROSTER, "query");
+const TQName TQN_ROSTER_QUERY(true, NS_ROSTER, "query");
const TQName TQN_ROSTER_ITEM(true, NS_ROSTER, "item");
const TQName TQN_ROSTER_GROUP(true, NS_ROSTER, "group");
-const TQName TQN_VCARD_TQUERY(true, NS_VCARD, "vCard");
+const TQName TQN_VCARD_QUERY(true, NS_VCARD, "vCard");
const TQName TQN_VCARD_FN(true, NS_VCARD, "FN");
const TQName TQN_XML_LANG(true, NS_XML, "lang");
@@ -308,11 +308,11 @@ const TQName TQN_CATEGORY(true, STR_EMPTY, "category");
const TQName TQN_VAR(true, STR_EMPTY, "var");
const std::string NS_DISCO_INFO("http://jabber.org/protocol/disco#info");
const std::string NS_DISCO_ITEMS("http://jabber.org/protocol/disco#items");
-const TQName TQN_DISCO_INFO_TQUERY(true, NS_DISCO_INFO, "query");
+const TQName TQN_DISCO_INFO_QUERY(true, NS_DISCO_INFO, "query");
const TQName TQN_DISCO_IDENTITY(true, NS_DISCO_INFO, "identity");
const TQName TQN_DISCO_FEATURE(true, NS_DISCO_INFO, "feature");
-const TQName TQN_DISCO_ITEMS_TQUERY(true, NS_DISCO_ITEMS, "query");
+const TQName TQN_DISCO_ITEMS_QUERY(true, NS_DISCO_ITEMS, "query");
const TQName TQN_DISCO_ITEM(true, NS_DISCO_ITEMS, "item");
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.h
index 52646e9f..1fa7fb48 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/constants.h
@@ -139,7 +139,7 @@ extern const TQName TQN_XSTREAM_XML_NOT_WELL_FORMED;
extern const TQName TQN_XSTREAM_TEXT;
extern const TQName TQN_TLS_STARTTLS;
-extern const TQName TQN_TLS_RETQUIRED;
+extern const TQName TQN_TLS_REQUIRED;
extern const TQName TQN_TLS_PROCEED;
extern const TQName TQN_TLS_FAILURE;
@@ -172,15 +172,15 @@ extern const TQName TQN_STANZA_ITEM_NOT_FOUND;
extern const TQName TQN_STANZA_JID_MALFORMED;
extern const TQName TQN_STANZA_NOT_ACCEPTABLE;
extern const TQName TQN_STANZA_NOT_ALLOWED;
-extern const TQName TQN_STANZA_PAYMENT_RETQUIRED;
+extern const TQName TQN_STANZA_PAYMENT_REQUIRED;
extern const TQName TQN_STANZA_RECIPIENT_UNAVAILABLE;
extern const TQName TQN_STANZA_REDIRECT;
-extern const TQName TQN_STANZA_REGISTRATION_RETQUIRED;
+extern const TQName TQN_STANZA_REGISTRATION_REQUIRED;
extern const TQName TQN_STANZA_REMOTE_SERVER_NOT_FOUND;
extern const TQName TQN_STANZA_REMOTE_SERVER_TIMEOUT;
extern const TQName TQN_STANZA_RESOURCE_CONSTRAINT;
extern const TQName TQN_STANZA_SERVICE_UNAVAILABLE;
-extern const TQName TQN_STANZA_SUBSCRIPTION_RETQUIRED;
+extern const TQName TQN_STANZA_SUBSCRIPTION_REQUIRED;
extern const TQName TQN_STANZA_UNDEFINED_CONDITION;
extern const TQName TQN_STANZA_UNEXPECTED_REQUEST;
extern const TQName TQN_STANZA_TEXT;
@@ -215,7 +215,7 @@ extern const TQName TQN_SERVER_ERROR;
extern const TQName TQN_SESSION_SESSION;
-extern const TQName TQN_PRIVACY_TQUERY;
+extern const TQName TQN_PRIVACY_QUERY;
extern const TQName TQN_PRIVACY_ACTIVE;
extern const TQName TQN_PRIVACY_DEFAULT;
extern const TQName TQN_PRIVACY_LIST;
@@ -225,11 +225,11 @@ extern const TQName TQN_PRIVACY_MESSAGE;
extern const TQName TQN_PRIVACY_PRESENCE_IN;
extern const TQName TQN_PRIVACY_PRESENCE_OUT;
-extern const TQName TQN_ROSTER_TQUERY;
+extern const TQName TQN_ROSTER_QUERY;
extern const TQName TQN_ROSTER_ITEM;
extern const TQName TQN_ROSTER_GROUP;
-extern const TQName TQN_VCARD_TQUERY;
+extern const TQName TQN_VCARD_QUERY;
extern const TQName TQN_VCARD_FN;
extern const TQName TQN_XML_LANG;
@@ -275,11 +275,11 @@ extern const TQName TQN_VAR;
extern const std::string NS_DISCO_INFO;
extern const std::string NS_DISCO_ITEMS;
-extern const TQName TQN_DISCO_INFO_TQUERY;
+extern const TQName TQN_DISCO_INFO_QUERY;
extern const TQName TQN_DISCO_IDENTITY;
extern const TQName TQN_DISCO_FEATURE;
-extern const TQName TQN_DISCO_ITEMS_TQUERY;
+extern const TQName TQN_DISCO_ITEMS_QUERY;
extern const TQName TQN_DISCO_ITEM;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h
index e20a8fee..ef8f2ea8 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h
@@ -53,15 +53,15 @@ enum XmppStanzaError {
XSE_JID_MALFORMED,
XSE_NOT_ACCEPTABLE,
XSE_NOT_ALLOWED,
- XSE_PAYMENT_RETQUIRED,
+ XSE_PAYMENT_REQUIRED,
XSE_RECIPIENT_UNAVAILABLE,
XSE_REDIRECT,
- XSE_REGISTRATION_RETQUIRED,
+ XSE_REGISTRATION_REQUIRED,
XSE_SERVER_NOT_FOUND,
XSE_SERVER_TIMEOUT,
XSE_RESOURCE_CONSTRAINT,
XSE_SERVICE_UNAVAILABLE,
- XSE_SUBSCRIPTION_RETQUIRED,
+ XSE_SUBSCRIPTION_REQUIRED,
XSE_UNDEFINED_CONDITION,
XSE_UNEXPECTED_REQUEST,
};
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc
index cdcfa9e7..38304048 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc
@@ -161,8 +161,8 @@ AddErrorCode(XmlElement * error_element, XmppStanzaError code) {
case XSE_NOT_ALLOWED:
AecImpl(error_element, TQN_STANZA_NOT_ALLOWED, "cancel", "405");
break;
- case XSE_PAYMENT_RETQUIRED:
- AecImpl(error_element, TQN_STANZA_PAYMENT_RETQUIRED, "auth", "402");
+ case XSE_PAYMENT_REQUIRED:
+ AecImpl(error_element, TQN_STANZA_PAYMENT_REQUIRED, "auth", "402");
break;
case XSE_RECIPIENT_UNAVAILABLE:
AecImpl(error_element, TQN_STANZA_RECIPIENT_UNAVAILABLE, "wait", "404");
@@ -170,8 +170,8 @@ AddErrorCode(XmlElement * error_element, XmppStanzaError code) {
case XSE_REDIRECT:
AecImpl(error_element, TQN_STANZA_REDIRECT, "modify", "302");
break;
- case XSE_REGISTRATION_RETQUIRED:
- AecImpl(error_element, TQN_STANZA_REGISTRATION_RETQUIRED, "auth", "407");
+ case XSE_REGISTRATION_REQUIRED:
+ AecImpl(error_element, TQN_STANZA_REGISTRATION_REQUIRED, "auth", "407");
break;
case XSE_SERVER_NOT_FOUND:
AecImpl(error_element, TQN_STANZA_REMOTE_SERVER_NOT_FOUND,
@@ -186,8 +186,8 @@ AddErrorCode(XmlElement * error_element, XmppStanzaError code) {
case XSE_SERVICE_UNAVAILABLE:
AecImpl(error_element, TQN_STANZA_SERVICE_UNAVAILABLE, "cancel", "503");
break;
- case XSE_SUBSCRIPTION_RETQUIRED:
- AecImpl(error_element, TQN_STANZA_SUBSCRIPTION_RETQUIRED, "auth", "407");
+ case XSE_SUBSCRIPTION_REQUIRED:
+ AecImpl(error_element, TQN_STANZA_SUBSCRIPTION_REQUIRED, "auth", "407");
break;
case XSE_UNDEFINED_CONDITION:
AecImpl(error_element, TQN_STANZA_UNDEFINED_CONDITION, "wait", "500");
diff --git a/kopete/protocols/msn/webcam/libmimic/mimic-private.h b/kopete/protocols/msn/webcam/libmimic/mimic-private.h
index 245793fb..adf59291 100644
--- a/kopete/protocols/msn/webcam/libmimic/mimic-private.h
+++ b/kopete/protocols/msn/webcam/libmimic/mimic-private.h
@@ -21,9 +21,9 @@
#include "mimic.h"
#define ENCODER_BUFFER_SIZE 16384
-#define ENCODER_TQUALITY_DEFAULT 0
-#define ENCODER_TQUALITY_MIN 0
-#define ENCODER_TQUALITY_MAX 10000
+#define ENCODER_QUALITY_DEFAULT 0
+#define ENCODER_QUALITY_MIN 0
+#define ENCODER_QUALITY_MAX 10000
struct _MimCtx {
gboolean encoder_initialized;
diff --git a/kopete/protocols/msn/webcam/libmimic/mimic.c b/kopete/protocols/msn/webcam/libmimic/mimic.c
index 2013022d..61abf9e8 100644
--- a/kopete/protocols/msn/webcam/libmimic/mimic.c
+++ b/kopete/protocols/msn/webcam/libmimic/mimic.c
@@ -155,7 +155,7 @@ gboolean mimic_encoder_init(MimCtx *ctx, const MimicResEnum resolution)
mimic_init(ctx, width, height);
/* Set a default quality setting. */
- ctx->quality = ENCODER_TQUALITY_DEFAULT;
+ ctx->quality = ENCODER_QUALITY_DEFAULT;
ctx->encoder_initialized = TRUE;
@@ -300,8 +300,8 @@ gboolean mimic_set_property(MimCtx *ctx, const gchar *name, gpointer data)
if (strcmp(name, "quality") == 0) {
gint new_quality = *((gint *) data);
- if (new_quality < ENCODER_TQUALITY_MIN ||
- new_quality > ENCODER_TQUALITY_MAX)
+ if (new_quality < ENCODER_QUALITY_MIN ||
+ new_quality > ENCODER_QUALITY_MAX)
{
return FALSE;
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.c
index 6d410392..cb69904c 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/mediastreamer/msfilter.c
@@ -130,7 +130,7 @@ int ms_filter_add_link(MSFilter *m1, MSFilter *m2)
if ((m1_q!=-1) && (m2_q!=-1)){
/* link with queues */
ms_trace("m1_q=%i , m2_q=%i",m1_q,m2_q);
- return ms_filter_link(m1,m1_q,m2,m2_q,LINK_TQUEUE);
+ return ms_filter_link(m1,m1_q,m2,m2_q,LINK_QUEUE);
}
if ((m1_f!=-1) && (m2_f!=-1)){
/* link with queues */
@@ -146,7 +146,7 @@ int ms_filter_add_link(MSFilter *m1, MSFilter *m2)
* @pin1: The pin number on @m1.
* @m2: A #MSFilter object.
* @pin2: The pin number on @m2.
* @linktype: Type of connection, it may be #LINK_TQUEUE, #LINK_FIFOS.
*
* This function links two MSFilter object between them. It must be used to make chains of filters.
* All data outgoing from pin1 of m1 will go to the input pin2 of m2.
@@ -165,7 +165,7 @@ int ms_filter_link(MSFilter *m1, gint pin1, MSFilter *m2,gint pin2, int linktype
g_message("ms_filter_add_link: %s,%i -> %s,%i",m1->klass->name,pin1,m2->klass->name,pin2);
switch(linktype)
{
- case LINK_TQUEUE:
+ case LINK_QUEUE:
/* Are filter m1 and m2 able to accept more queues connections ?*/
g_return_val_if_fail(m1->qoutputs<MS_FILTER_GET_CLASS(m1)->max_qoutputs,-EMLINK);
g_return_val_if_fail(m2->qinputs<MS_FILTER_GET_CLASS(m2)->max_qinputs,-EMLINK);
@@ -244,7 +244,7 @@ int ms_filter_link(MSFilter *m1, gint pin1, MSFilter *m2,gint pin2, int linktype
* @pin1: The pin number on @m1.
* @m2: A #MSFilter object.
* @pin2: The pin number on @m2.
* @linktype: Type of connection, it may be #LINK_TQUEUE, #LINK_FIFOS.
*
* Unlink @pin1 of filter @m1 from @pin2 of filter @m2. @linktype specifies what type of connection is removed.
*
@@ -254,7 +254,7 @@ int ms_filter_unlink(MSFilter *m1, gint pin1, MSFilter *m2,gint pin2,gint linkty
{
switch(linktype)
{
- case LINK_TQUEUE:
+ case LINK_QUEUE:
/* Are filter m1 and m2 valid with their inputs and outputs ?*/
g_return_val_if_fail(m1->outqueues!=NULL,-EFAULT);
g_return_val_if_fail(m2->inqueues!=NULL,-EFAULT);
@@ -321,7 +321,7 @@ gint ms_filter_remove_links(MSFilter *m1, MSFilter *m2)
if (rmf==m2){
j=find_iq(rmf,qo);
if (j==-1) g_error("Could not find input queue: impossible case.");
- ms_filter_unlink(m1,i,m2,j,LINK_TQUEUE);
+ ms_filter_unlink(m1,i,m2,j,LINK_QUEUE);
removed=0;
}
}
@@ -146,7 +146,7 @@ int ms_filter_add_link(MSFilter *m1, MSFilter *m2)
* @m2: A #MSFilter object.
* @pin2: The pin number on @m2.
- * @linktype: Type of connection, it may be #LINK_TQUEUE, #LINK_FIFOS.
+ * @linktype: Type of connection, it may be #LINK_QUEUE, #LINK_FIFOS.
*
* This function links two MSFilter object between them. It must be used to make chains of filters.
@@ -244,7 +244,7 @@ int ms_filter_link(MSFilter *m1, gint pin1, MSFilter *m2,gint pin2, int linktype
* @m2: A #MSFilter object.
* @pin2: The pin number on @m2.
- * @linktype: Type of connection, it may be #LINK_TQUEUE, #LINK_FIFOS.
+ * @linktype: Type of connection, it may be #LINK_QUEUE, #LINK_FIFOS.
*
* Unlink @pin1 of filter @m1 from @pin2 of filter @m2. @linktype specifies what type of connection is removed.